@@ -22,8 +22,8 @@ DATA = dict(
             payload=b'123',
         ),
         ],
-    from_values=EmailAddress('Sender', 'status@sender.com', 'Sender <status@sender.com>'),
-    to_values=(EmailAddress('Data Email', 'data@email.com', 'Data Email <data@email.com>'),),
+    from_values=EmailAddress(name='Sender', email='status@sender.com'),
+    to_values=(EmailAddress(name='Data Email', email='data@email.com'),),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
