@@ -22,8 +22,8 @@ DATA = dict(
             payload=b'puts "Hello, world!"\r\ngets\r\n',
         ),
         ],
-    from_values=EmailAddress('', 'foo@example.com', 'foo@example.com'),
-    to_values=(EmailAddress('', 'blah@example.com', 'blah@example.com'),),
+    from_values=EmailAddress(name='', email='foo@example.com'),
+    to_values=(EmailAddress(name='', email='blah@example.com'),),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
