@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'date': ('Tue, 20 Apr 2021 12:31:24 +0500',), 'from': ('<bit@ufo.ru>',), 'subject': ('TTT: 1/20.1.UFA Depart',), 'mime-version': ('1.0',), 'message-id': ('<2104200731.1@ufo.ru>',), 'content-transfer-encoding': ('Base64',), 'to': ('<aaa@u6.ru>, <Serg@ufo.ru>, <isg@ggg.ru>',), 'content-type': ('multipart/mixed; charset="utf-8";\r\n\tboundary="96b0f72f_a01e_44f0_8595_352ca3ba6fd4"',)},
     attachments=[],
-    from_values=EmailAddress('', 'bit@ufo.ru', 'bit@ufo.ru'),
-    to_values=(EmailAddress('', 'aaa@u6.ru', 'aaa@u6.ru'), EmailAddress('', 'Serg@ufo.ru', 'Serg@ufo.ru'), EmailAddress('', 'isg@ggg.ru', 'isg@ggg.ru')),
+    from_values=EmailAddress(name='', email='bit@ufo.ru'),
+    to_values=(EmailAddress(name='', email='aaa@u6.ru'), EmailAddress(name='', email='Serg@ufo.ru'), EmailAddress(name='', email='isg@ggg.ru')),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
