@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'message-id': ('<001301c17797$9cd0ef30$a3ab620c@vaio>',), 'from': ('"SCS_2" <redacted@attglobal.net>',), 'to': ('<Undisclosed-Recipient:@mailman.enron.com;>',), 'subject': ('REDACTED',), 'date': ('Tue, 27 Nov 2001 15:02:35 -0800',), 'mime-version': ('1.0',), 'content-type': ('multipart/mixed;\r\n\tboundary="----=_NextPart_000_000F_01C17754.8C3CAF30"',), 'x-priority': ('3',), 'x-msmail-priority': ('Normal',), 'x-mailer': ('Microsoft Outlook Express 5.00.2919.6700',), 'x-mimeole': ('Produced By Microsoft MimeOLE V5.00.2919.6700',), 'return-path': ('redacted@attglobal.net',)},
     attachments=[],
-    from_values=EmailAddress('SCS_2', 'redacted@attglobal.net', 'SCS_2 <redacted@attglobal.net>'),
-    to_values=(EmailAddress('', '', 'Undisclosed-Recipient'), EmailAddress('', '@mailman.enron.com', '@mailman.enron.com')),
+    from_values=EmailAddress(name='SCS_2', email='redacted@attglobal.net'),
+    to_values=(EmailAddress(name='Undisclosed-Recipient', email=''), EmailAddress(name='', email='@mailman.enron.com')),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
