@@ -14,8 +14,8 @@ DATA = dict(
     html='<p>foo</p>\n',
     headers={'from': ('<redacted@flashmail.net>',), 'subject': ('Redacted',), 'to': ('<redacted@Enron.com>',), 'message-id': ('<105647271315.NCV17523@x263.net>',), 'mime-version': ('1.0',), 'content-type': ('text/html;\n charset=utf-8',), 'content-disposition': ('=?utf-8?Q?invalid?=', '=?utf-8?Q?invalid?='), 'content-transfer-encoding': ('quoted-printable',)},
     attachments=[],
-    from_values=EmailAddress('', 'redacted@flashmail.net', 'redacted@flashmail.net'),
-    to_values=(EmailAddress('', 'redacted@Enron.com', 'redacted@Enron.com'),),
+    from_values=EmailAddress(name='', email='redacted@flashmail.net'),
+    to_values=(EmailAddress(name='', email='redacted@Enron.com'),),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
