@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'mime-version': ('1.0 (Apple Message framework v619.2)',), 'to': ('"xxxxx@xxxxx" <matmail>',), 'message-id': ('<416eaebec6d333ec6939eaf8a7d80724@xxxxx>',), 'content-type': ('multipart/alternative;\r\n        boundary=Apple-Mail-5-1037861608',), 'from': ('"xxxxx@xxxxx" <xxxxx@xxxxx>',), 'subject': ('worse when you use them.',), 'date': ('Wed, 27 Apr 2005 14:15:31 -0700',)},
     attachments=[],
-    from_values=EmailAddress('xxxxx@xxxxx', 'xxxxx@xxxxx', 'xxxxx@xxxxx <xxxxx@xxxxx>'),
-    to_values=(EmailAddress('xxxxx@xxxxx', '', 'xxxxx@xxxxx <matmail>'),),
+    from_values=EmailAddress(name='xxxxx@xxxxx', email='xxxxx@xxxxx'),
+    to_values=(EmailAddress(name='xxxxx@xxxxx', email=''),),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
