@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'delivered-to': ('unknown@example.com',), 'date': ('Wed, 28 May 2014 17:18:19 +0900 (JST)',), 'from': ('xxxxxxx@docomo.ne.jp',), 'to': ('unknown@example.com',), 'subject': ('test',), 'message-id': ('<xxxxx@docomo.ne.jp>',), 'mime-version': ('1.0',), 'content-type': ('text/plain; charset="Shift_JIS"',), 'content-transfer-encoding': ('8bit',)},
     attachments=[],
-    from_values=EmailAddress('', 'xxxxxxx@docomo.ne.jp', 'xxxxxxx@docomo.ne.jp'),
-    to_values=(EmailAddress('', 'unknown@example.com', 'unknown@example.com'),),
+    from_values=EmailAddress(name='', email='xxxxxxx@docomo.ne.jp'),
+    to_values=(EmailAddress(name='', email='unknown@example.com'),),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
