@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'mime-version': ('1.0 (Apple Message framework v622)',), 'content-transfer-encoding': ('base64',), 'message-id': ('<d3b8cf8e49f0448085@0c28713a1@f473e@37signals.com>',), 'content-type': ('text/plain;\r\n  charset=EUC-KR;\r\n  format=flowed',), 'to': ('willard15georgina@jamis.backpackit.com',), 'from': ('Jamis Buck <jamis@37signals.com>',), 'subject': ('=?EUC-KR?Q?NOTE:_=C7=D1=B1=B9=B8=BB=B7=CE_=C7=CF=B4=C2_=B0=CD?=',), 'date': ('Mon, 2 May 2005 16:07:05 -0600',)},
     attachments=[],
-    from_values=EmailAddress('Jamis Buck', 'jamis@37signals.com', 'Jamis Buck <jamis@37signals.com>'),
-    to_values=(EmailAddress('', 'willard15georgina@jamis.backpackit.com', 'willard15georgina@jamis.backpackit.com'),),
+    from_values=EmailAddress(name='Jamis Buck', email='jamis@37signals.com'),
+    to_values=(EmailAddress(name='', email='willard15georgina@jamis.backpackit.com'),),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
