@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'from': ('John Doe <jdoe@machine.example>',), 'sender': ('Michael Jones <mjones@machine.example>',), 'to': ('Mary Smith <mary@example.net>',), 'subject': ('Saying Hello',), 'date': ('Fri, 21 Nov 1997 09:55:06 -0600',), 'message-id': ('<1234@local.machine.example>',)},
     attachments=[],
-    from_values=EmailAddress('John Doe', 'jdoe@machine.example', 'John Doe <jdoe@machine.example>'),
-    to_values=(EmailAddress('Mary Smith', 'mary@example.net', 'Mary Smith <mary@example.net>'),),
+    from_values=EmailAddress(name='John Doe', email='jdoe@machine.example'),
+    to_values=(EmailAddress(name='Mary Smith', email='mary@example.net'),),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
