@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'from': ('Pete <pete@silly.example>',), 'to': ('A Group:Chris Jones <c@a.test>,joe@where.test,John <jdoe@one.test>;',), 'cc': ('Undisclosed recipients:;',), 'date': ('Thu, 13 Feb 1969 23:32:54 -0330',), 'message-id': ('<testabcd.1234@silly.example>',)},
     attachments=[],
-    from_values=EmailAddress('Pete', 'pete@silly.example', 'Pete <pete@silly.example>'),
-    to_values=(EmailAddress('Chris Jones', 'c@a.test', 'Chris Jones <c@a.test>'), EmailAddress('', 'joe@where.test', 'joe@where.test'), EmailAddress('John', 'jdoe@one.test', 'John <jdoe@one.test>')),
+    from_values=EmailAddress(name='Pete', email='pete@silly.example'),
+    to_values=(EmailAddress(name='Chris Jones', email='c@a.test'), EmailAddress(name='', email='joe@where.test'), EmailAddress(name='John', email='jdoe@one.test')),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
