@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'to': ('"Mary Smith: Personal Account" <smith@home.example>',), 'from': ('John Doe <jdoe@machine.example>',), 'subject': ('Re: Saying Hello',), 'date': ('Fri, 21 Nov 1997 11:00:00 -0600',), 'message-id': ('<abcd.1234@local.machine.tld>',), 'in-reply-to': ('<3456@example.net>',), 'references': ('<1234@local.machine.example> <3456@example.net>',)},
     attachments=[],
-    from_values=EmailAddress('John Doe', 'jdoe@machine.example', 'John Doe <jdoe@machine.example>'),
-    to_values=(EmailAddress('Mary Smith: Personal Account', 'smith@home.example', 'Mary Smith: Personal Account <smith@home.example>'),),
+    from_values=EmailAddress(name='John Doe', email='jdoe@machine.example'),
+    to_values=(EmailAddress(name='Mary Smith: Personal Account', email='smith@home.example'),),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
