@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'from': ('Joe Q. Public <john.q.public@example.com>',), 'to': ('Mary Smith <@machine.tld:mary@example.net>, , jdoe@test   . example',), 'date': ('Tue, 1 Jul 2003 10:52:37 +0200',), 'message-id': ('<5678.21-Nov-1997@example.com>',)},
     attachments=[],
-    from_values=EmailAddress('Joe Q. Public', 'john.q.public@example.com', 'Joe Q. Public <john.q.public@example.com>'),
-    to_values=(EmailAddress('Mary Smith', 'mary@example.net', 'Mary Smith <mary@example.net>'), EmailAddress('', 'jdoe@test.example', 'jdoe@test.example')),
+    from_values=EmailAddress(name='Joe Q. Public', email='john.q.public@example.com'),
+    to_values=(EmailAddress(name='Mary Smith', email='mary@example.net'), EmailAddress(name='', email='jdoe@test.example')),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
